@@ -27,15 +27,15 @@ build_time_vars = {'ABIFLAGS': '',
            '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
            '-Werror=format-security         -fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug -march=armv8-a '
-           '-O3 -pipe -fstack-protector-strong -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug -march=armv8-a '
-           '-O3 -pipe -fstack-protector-strong -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug',
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+           '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+           '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -45,7 +45,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wformat -Werror=format-security         '
                      '-fstack-clash-protection -g '
-                     '-ffile-prefix-map=/build/python/src=/usr/src/debug',
+                     '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -63,7 +63,7 @@ build_time_vars = {'ABIFLAGS': '',
                 '-O3 -pipe -fstack-protector-strong -fno-plt '
                 '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                 '-Werror=format-security         -fstack-clash-protection -g '
-                "-ffile-prefix-map=/build/python/src=/usr/src/debug' "
+                "-ffile-prefix-map=/build/python/src=/usr/src/debug/python' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
@@ -670,19 +670,19 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                              '-march=armv8-a -O3 -pipe '
                              '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                              '-march=armv8-a -O3 -pipe '
                              '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                              '-std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
@@ -693,15 +693,15 @@ build_time_vars = {'ABIFLAGS': '',
               '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
               '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
               '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug',
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
@@ -712,15 +712,17 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wformat -Werror=format-security         '
                    '-fstack-clash-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-g -ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-g '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-g -ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-g '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -741,17 +743,17 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
                         '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                         '-march=armv8-a -O3 -pipe -fstack-protector-strong '
                         '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wformat -Werror=format-security         '
                         '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                         '-march=armv8-a -O3 -pipe -fstack-protector-strong '
                         '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wformat -Werror=format-security         '
                         '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                         '-std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
